django_celery_results.models — django_celery_results 1.0.0 documentation

# `django_celery_results.models`

class `django_celery_results.models.` `TaskResult`(*args, **kwargs)

  Task result/status.

  exception `DoesNotExist`
  exception `TaskResult.` `MultipleObjectsReturned`
  `TaskResult.` `as_dict`()
  `TaskResult.` `get_next_by_date_done`(*moreargs, **morekwargs)
  `TaskResult.` `get_previous_by_date_done`(*moreargs, **morekwargs)
  `TaskResult.` `get_status_display`(*moreargs, **morekwargs)
  `TaskResult.` `objects` = <django_celery_results.managers.TaskResultManager object>